#' Data for examples
#'
#' Supporting data sets to use in the examples. They will be used in the
#' examples. example.ammonite.svg and log.loop.tex are meant to generate their
#' respective .svg and .tex files.
#'
#'\describe{
#'   \item{\strong{Litholog drawing data}}{bed.example, boundary.example,
#'   example.ammonite, example.ammonite.svg, example.belemnite, example.breccia,
#'   example.lense, example.liquefaction, fossil.example, proxy.example,
#'   proxy.example.litho}
#'   \item{\strong{Magnetostratigraphical data}}{chron.example}
#'   \item{\strong{Litholog exportation script}}{log.loop.tex}
#'   \item{\strong{Oriented data}}{zeq_example}
#'   \item{\strong{Stratigraphical tie points}}{tie.points.example}
#' }
#'
#' @name StratigrapheR.examples
NULL

#' @rdname StratigrapheR.examples
#' @name tie.points.example
NULL

#' @rdname StratigrapheR.examples
#' @name bed.example
NULL


#' @rdname StratigrapheR.examples
#' @name boundary.example
NULL

#' @rdname StratigrapheR.examples
#' @name chron.example
NULL

#' @rdname StratigrapheR.examples
#' @name example.ammonite
NULL

#' @rdname StratigrapheR.examples
#' @name example.ammonite.svg
NULL

#' @rdname StratigrapheR.examples
#' @name example.belemnite
NULL

#' @rdname StratigrapheR.examples
#' @name example.breccia
NULL

#' @rdname StratigrapheR.examples
#' @name example.lense
NULL

#' @rdname StratigrapheR.examples
#' @name example.liquefaction
NULL

#' @rdname StratigrapheR.examples
#' @name fossil.example
NULL

#' @rdname StratigrapheR.examples
#' @name log.loop.tex
NULL

#' @rdname StratigrapheR.examples
#' @name noise_emd
NULL

#' @rdname StratigrapheR.examples
#' @name proxy.example
NULL

#' @rdname StratigrapheR.examples
#' @name proxy.example.litho
NULL

#' @rdname StratigrapheR.examples
#' @name zeq_example
NULL

